@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/Xext/xvmc.c,v 1.11 2005/10/14 15:16:12 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/Xext/xvmc.c,v 1.12 2007/01/04 02:48:11 tsi Exp $ */
 
 #define NEED_REPLIES
 #define NEED_EVENTS
@@ -575,7 +575,7 @@ SProcXvMCDispatch(ClientPtr client)
 }
 
 void 
-XvMCExtensionInit()
+XvMCExtensionInit(INITARGS)
 {
    ExtensionEntry *extEntry;
 
