@@ -1,4 +1,3 @@
-/* $Xorg: xkbInit.c,v 1.3 2000/08/17 19:53:47 cpqbld Exp $ */
 /************************************************************
 Copyright (c) 1993 by Silicon Graphics Computer Systems, Inc.
 
@@ -24,7 +23,7 @@ OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
 THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/programs/Xserver/xkb/xkbInit.c,v 3.32 2003/11/17 22:20:46 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/xkb/xkbInit.c,v 3.37 2006/09/02 16:44:24 dawes Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,8 +40,8 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include "opaque.h"
 #include "property.h"
 #define	XKBSRV_NEED_FILE_FUNCS
-#include "XKBsrv.h"
-#include "XKBgeom.h"
+#include <X11/extensions/XKBsrv.h>
+#include <X11/extensions/XKBgeom.h>
 #include <X11/extensions/XKMformat.h>
 #include <X11/extensions/XKBfile.h>
 #include "xkb.h"
@@ -113,11 +112,11 @@ typedef struct	_SrvXkmInfo {
 #define	XKB_DFLT_RULES_PROP	True
 #endif
 
-char	*		XkbBaseDirectory=	XKB_BASE_DIRECTORY;
+const char	*	XkbBaseDirectory=	XKB_BASE_DIRECTORY;
 char	*		XkbInitialMap=		NULL;
 int	 		XkbWantAccessX=		0;	
 static XkbFileInfo *	_XkbInitFileInfo=	NULL;
-char *			XkbDB=			NULL;
+const char *		XkbDB=			NULL;
 int			XkbAutoLoad=		1;
 
 static Bool		rulesDefined=		False;
@@ -310,7 +309,7 @@ XkbInitRadioGroups(XkbSrvInfoPtr xkbi,SrvXkmInfo *file)
 static Status
 XkbInitCompatStructs(XkbDescPtr xkb,SrvXkmInfo *file)
 {
-register int 	i;
+int 	i;
 XkbCompatMapPtr	compat;
 
     if (file->xkbinfo.defined&XkmCompatMapMask)
@@ -624,6 +623,7 @@ XkbRF_VarDefsRec	defs;
     pMods= pModsIn;
     bzero(&defs,sizeof(XkbRF_VarDefsRec));
     bzero(&cfgNames,sizeof(XkbComponentNamesRec));
+    bzero(&finfo, sizeof(finfo));
     rules= XkbGetRulesDflts(&defs);
     config= XkbDDXPreloadConfig(&rules,&defs,&cfgNames,dev);
 
@@ -716,7 +716,7 @@ XkbRF_VarDefsRec	defs;
 
     if (ok && (finfo.xkb!=NULL)) {
 	XkbDescPtr	xkb;
-	int		minKC,maxKC;
+	KeyCode		minKC,maxKC;
 
 	xkb= finfo.xkb;
 	minKC= xkb->min_key_code;
@@ -890,7 +890,7 @@ extern unsigned int	XkbDfltAccessXFeedback;
 extern unsigned char	XkbDfltAccessXOptions;
 
 int
-XkbProcessArguments(int argc,char *argv[],int i)
+XkbProcessArguments(int argc,const char *argv[],int i)
 {
     if (strcmp(argv[i],"-kb")==0) {
 	noXkbExtension= True;
@@ -925,7 +925,7 @@ XkbProcessArguments(int argc,char *argv[],int i)
     else if (strncmp(argv[i], "-xkbmap", 7) == 0) {
 	if(++i < argc) {
 	    if (strlen(argv[i]) < PATH_MAX) {
-		XkbInitialMap= argv[i];
+		XkbInitialMap= xstrdup(argv[i]);
 		return 2;
 	    } else {
 		LogMessage(X_ERROR, "-xkbmap pathname too long\n");
