@@ -1,4 +1,4 @@
-/* $Xorg: gfx.c,v 1.4 2001/02/09 02:05:31 xorgcvs Exp $ */
+/* $XFree86: xc/programs/lbxproxy/di/gfx.c,v 1.8 2005/10/14 15:17:30 tsi Exp $ */
 /*
 
 Copyright 1998  The Open Group
@@ -46,7 +46,6 @@ in this Software without prior written authorization from The Open Group.
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
  */
-/* $XFree86: xc/programs/lbxproxy/di/gfx.c,v 1.7 2004/04/03 22:38:53 tsi Exp $ */
 
 /*
  * graphics acceleration
@@ -59,7 +58,7 @@ in this Software without prior written authorization from The Open Group.
 #include	"util.h"
 #include	"resource.h"
 #include	"wire.h"
-#include        "lbximage.h"
+#include        <X11/extensions/lbximage.h>
 #include	"proxyopts.h"
 #include	"swap.h"
 #include        "gfx.h"
